@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '2.06';
+$HTTP::BrowserDetect::VERSION = '2.07';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -455,6 +455,9 @@ sub _init_core {
 
     my $ua = lc $self->{user_agent};
 
+    # any UA via Google Translate gets this appended
+    $ua =~ s{,gzip\(gfe\)\z}{};
+
     # These get filled in immediately
     $self->{tests}         = {};
     $self->{browser_tests} = {};
@@ -2441,7 +2444,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 2.06
+version 2.07
 
 =head1 SYNOPSIS
 
